---
title: <span class="badge object-type-scalar"></span> Radians
---
# <span class="badge object-type-scalar"></span> Radians

Angle: Radians

## Definition

```python
# Angle: Radians
Radians: typing.Literal["radian"] = "radian"
```
